/****************************************************************************
** Meta object code from reading C++ file 'qquick3dshaderutils_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dshaderutils_p.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dshaderutils_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31QQuick3DShaderUtilsTextureInputE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsTextureInput::qt_create_metaobjectdata<qt_meta_tag_ZN31QQuick3DShaderUtilsTextureInputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsTextureInput",
        "QML.Element",
        "TextureInput",
        "textureChanged",
        "",
        "enabledChanged",
        "setTexture",
        "QQuick3DTexture*",
        "texture",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textureChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTexture'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'texture'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsTextureInput, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsTextureInput::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQuick3DShaderUtilsTextureInputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQuick3DShaderUtilsTextureInputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QQuick3DShaderUtilsTextureInputE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsTextureInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsTextureInput *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textureChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->setTexture((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsTextureInput::*)()>(_a, &QQuick3DShaderUtilsTextureInput::textureChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsTextureInput::*)()>(_a, &QQuick3DShaderUtilsTextureInput::enabledChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->texture(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTexture(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->enabled, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->enabledChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsTextureInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsTextureInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QQuick3DShaderUtilsTextureInputE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DShaderUtilsTextureInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsTextureInput::textureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DShaderUtilsTextureInput::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN25QQuick3DShaderUtilsBufferE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsBuffer::qt_create_metaobjectdata<qt_meta_tag_ZN25QQuick3DShaderUtilsBufferE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsBuffer",
        "QML.Element",
        "Buffer",
        "changed",
        "",
        "format",
        "TextureFormat",
        "textureFilterOperation",
        "TextureFilterOperation",
        "textureCoordOperation",
        "TextureCoordOperation",
        "sizeMultiplier",
        "bufferFlags",
        "AllocateBufferFlagValues",
        "name",
        "Unknown",
        "Nearest",
        "Linear",
        "ClampToEdge",
        "MirroredRepeat",
        "Repeat",
        "None",
        "SceneLifetime",
        "RGBA8",
        "RGBA16F",
        "RGBA32F",
        "R8",
        "R16",
        "R16F",
        "R32F"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'format'
        QtMocHelpers::PropertyData<enum TextureFormat>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'textureFilterOperation'
        QtMocHelpers::PropertyData<enum TextureFilterOperation>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'textureCoordOperation'
        QtMocHelpers::PropertyData<enum TextureCoordOperation>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sizeMultiplier'
        QtMocHelpers::PropertyData<float>(11, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'bufferFlags'
        QtMocHelpers::PropertyData<enum AllocateBufferFlagValues>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QByteArray>(14, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TextureFilterOperation'
        QtMocHelpers::EnumData<enum TextureFilterOperation>(8, 8, QMC::EnumIsScoped).add({
            {   15, TextureFilterOperation::Unknown },
            {   16, TextureFilterOperation::Nearest },
            {   17, TextureFilterOperation::Linear },
        }),
        // enum 'TextureCoordOperation'
        QtMocHelpers::EnumData<enum TextureCoordOperation>(10, 10, QMC::EnumIsScoped).add({
            {   15, TextureCoordOperation::Unknown },
            {   18, TextureCoordOperation::ClampToEdge },
            {   19, TextureCoordOperation::MirroredRepeat },
            {   20, TextureCoordOperation::Repeat },
        }),
        // enum 'AllocateBufferFlagValues'
        QtMocHelpers::EnumData<enum AllocateBufferFlagValues>(13, 13, QMC::EnumIsScoped).add({
            {   21, AllocateBufferFlagValues::None },
            {   22, AllocateBufferFlagValues::SceneLifetime },
        }),
        // enum 'TextureFormat'
        QtMocHelpers::EnumData<enum TextureFormat>(6, 6, QMC::EnumIsScoped).add({
            {   15, TextureFormat::Unknown },
            {   23, TextureFormat::RGBA8 },
            {   24, TextureFormat::RGBA16F },
            {   25, TextureFormat::RGBA32F },
            {   26, TextureFormat::R8 },
            {   27, TextureFormat::R16 },
            {   28, TextureFormat::R16F },
            {   29, TextureFormat::R32F },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsBuffer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsBuffer::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DShaderUtilsBufferE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DShaderUtilsBufferE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQuick3DShaderUtilsBufferE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsBuffer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsBuffer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsBuffer::*)()>(_a, &QQuick3DShaderUtilsBuffer::changed, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum TextureFormat*>(_v) = _t->format(); break;
        case 1: *reinterpret_cast<enum TextureFilterOperation*>(_v) = _t->textureFilterOperation(); break;
        case 2: *reinterpret_cast<enum TextureCoordOperation*>(_v) = _t->textureCoordOperation(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->sizeMultiplier; break;
        case 4: *reinterpret_cast<enum AllocateBufferFlagValues*>(_v) = _t->bufferFlags(); break;
        case 5: *reinterpret_cast<QByteArray*>(_v) = _t->name; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFormat(*reinterpret_cast<enum TextureFormat*>(_v)); break;
        case 1: _t->setTextureFilterOperation(*reinterpret_cast<enum TextureFilterOperation*>(_v)); break;
        case 2: _t->setTextureCoordOperation(*reinterpret_cast<enum TextureCoordOperation*>(_v)); break;
        case 3:
            if (QtMocHelpers::setProperty(_t->sizeMultiplier, *reinterpret_cast<float*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 4: _t->setBufferFlags(*reinterpret_cast<enum AllocateBufferFlagValues*>(_v)); break;
        case 5:
            if (QtMocHelpers::setProperty(_t->name, *reinterpret_cast<QByteArray*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsBuffer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsBuffer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DShaderUtilsBufferE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DShaderUtilsBuffer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsBuffer::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN32QQuick3DShaderUtilsRenderCommandE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderCommand::qt_create_metaobjectdata<qt_meta_tag_ZN32QQuick3DShaderUtilsRenderCommandE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderCommand",
        "QML.Element",
        "Command",
        "changed",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderCommand, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderCommand::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DShaderUtilsRenderCommandE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DShaderUtilsRenderCommandE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32QQuick3DShaderUtilsRenderCommandE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderCommand::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderCommand *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsRenderCommand::*)()>(_a, &QQuick3DShaderUtilsRenderCommand::changed, 0))
            return;
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderCommand::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderCommand::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DShaderUtilsRenderCommandE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderCommand::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsRenderCommand::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN30QQuick3DShaderUtilsBufferInputE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsBufferInput::qt_create_metaobjectdata<qt_meta_tag_ZN30QQuick3DShaderUtilsBufferInputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsBufferInput",
        "QML.Element",
        "BufferInput",
        "buffer",
        "QQuick3DShaderUtilsBuffer*",
        "sampler"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'buffer'
        QtMocHelpers::PropertyData<QQuick3DShaderUtilsBuffer*>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'sampler'
        QtMocHelpers::PropertyData<QByteArray>(5, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsBufferInput, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsBufferInput::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DShaderUtilsBufferInputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DShaderUtilsBufferInputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QQuick3DShaderUtilsBufferInputE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsBufferInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsBufferInput *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DShaderUtilsBuffer* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DShaderUtilsBuffer**>(_v) = _t->buffer(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->sampler; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBuffer(*reinterpret_cast<QQuick3DShaderUtilsBuffer**>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->sampler, *reinterpret_cast<QByteArray*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsBufferInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsBufferInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DShaderUtilsBufferInputE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsBufferInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN29QQuick3DRenderPassTargetBlendE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRenderPassTargetBlend::qt_create_metaobjectdata<qt_meta_tag_ZN29QQuick3DRenderPassTargetBlendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRenderPassTargetBlend",
        "QML.Element",
        "renderTargetBlend",
        "QML.AddedInVersion",
        "1547",
        "enable",
        "colorWrite",
        "ColorMask",
        "srcColor",
        "BlendFactor",
        "dstColor",
        "opColor",
        "BlendOperation",
        "srcAlpha",
        "dstAlpha",
        "opAlpha",
        "Zero",
        "One",
        "SrcColor",
        "OneMinusSrcColor",
        "DstColor",
        "OneMinusDstColor",
        "SrcAlpha",
        "OneMinusSrcAlpha",
        "DstAlpha",
        "OneMinusDstAlpha",
        "ConstantColor",
        "OneMinusConstantColor",
        "ConstantAlpha",
        "OneMinusConstantAlpha",
        "SrcAlphaSaturate",
        "Src1Color",
        "OneMinusSrc1Color",
        "Src1Alpha",
        "OneMinusSrc1Alpha",
        "Add",
        "Subtract",
        "ReverseSubtract",
        "Min",
        "Max"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enable'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'colorWrite'
        QtMocHelpers::PropertyData<ColorMask>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'srcColor'
        QtMocHelpers::PropertyData<enum BlendFactor>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'dstColor'
        QtMocHelpers::PropertyData<enum BlendFactor>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'opColor'
        QtMocHelpers::PropertyData<enum BlendOperation>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'srcAlpha'
        QtMocHelpers::PropertyData<enum BlendFactor>(13, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'dstAlpha'
        QtMocHelpers::PropertyData<enum BlendFactor>(14, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'opAlpha'
        QtMocHelpers::PropertyData<enum BlendOperation>(15, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BlendFactor'
        QtMocHelpers::EnumData<enum BlendFactor>(9, 9, QMC::EnumIsScoped).add({
            {   16, BlendFactor::Zero },
            {   17, BlendFactor::One },
            {   18, BlendFactor::SrcColor },
            {   19, BlendFactor::OneMinusSrcColor },
            {   20, BlendFactor::DstColor },
            {   21, BlendFactor::OneMinusDstColor },
            {   22, BlendFactor::SrcAlpha },
            {   23, BlendFactor::OneMinusSrcAlpha },
            {   24, BlendFactor::DstAlpha },
            {   25, BlendFactor::OneMinusDstAlpha },
            {   26, BlendFactor::ConstantColor },
            {   27, BlendFactor::OneMinusConstantColor },
            {   28, BlendFactor::ConstantAlpha },
            {   29, BlendFactor::OneMinusConstantAlpha },
            {   30, BlendFactor::SrcAlphaSaturate },
            {   31, BlendFactor::Src1Color },
            {   32, BlendFactor::OneMinusSrc1Color },
            {   33, BlendFactor::Src1Alpha },
            {   34, BlendFactor::OneMinusSrc1Alpha },
        }),
        // enum 'BlendOperation'
        QtMocHelpers::EnumData<enum BlendOperation>(12, 12, QMC::EnumIsScoped).add({
            {   35, BlendOperation::Add },
            {   36, BlendOperation::Subtract },
            {   37, BlendOperation::ReverseSubtract },
            {   38, BlendOperation::Min },
            {   39, BlendOperation::Max },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRenderPassTargetBlend, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DRenderPassTargetBlend::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DRenderPassTargetBlendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DRenderPassTargetBlendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQuick3DRenderPassTargetBlendE_t>.metaTypes,
    nullptr
} };

void QQuick3DRenderPassTargetBlend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QQuick3DRenderPassTargetBlend *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enable; break;
        case 1: *reinterpret_cast<ColorMask*>(_v) = _t->colorWrite; break;
        case 2: *reinterpret_cast<enum BlendFactor*>(_v) = _t->srcColor; break;
        case 3: *reinterpret_cast<enum BlendFactor*>(_v) = _t->dstColor; break;
        case 4: *reinterpret_cast<enum BlendOperation*>(_v) = _t->opColor; break;
        case 5: *reinterpret_cast<enum BlendFactor*>(_v) = _t->srcAlpha; break;
        case 6: *reinterpret_cast<enum BlendFactor*>(_v) = _t->dstAlpha; break;
        case 7: *reinterpret_cast<enum BlendOperation*>(_v) = _t->opAlpha; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->enable, *reinterpret_cast<bool*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->colorWrite, *reinterpret_cast<ColorMask*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->srcColor, *reinterpret_cast<enum BlendFactor*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->dstColor, *reinterpret_cast<enum BlendFactor*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->opColor, *reinterpret_cast<enum BlendOperation*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->srcAlpha, *reinterpret_cast<enum BlendFactor*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->dstAlpha, *reinterpret_cast<enum BlendFactor*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->opAlpha, *reinterpret_cast<enum BlendOperation*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN40QQuick3DShaderUtilsPipelineStateOverrideE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsPipelineStateOverride::qt_create_metaobjectdata<qt_meta_tag_ZN40QQuick3DShaderUtilsPipelineStateOverrideE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsPipelineStateOverride",
        "QML.Element",
        "PipelineStateOverride",
        "QML.AddedInVersion",
        "1547",
        "depthTestEnabledChanged",
        "",
        "depthWriteEnabledChanged",
        "blendEnabledChanged",
        "usesStencilReferenceChanged",
        "usesScissorChanged",
        "depthFunctionChanged",
        "cullModeChanged",
        "polygonModeChanged",
        "stencilWriteMaskChanged",
        "stencilReferenceChanged",
        "viewportChanged",
        "scissorChanged",
        "targetBlend0Changed",
        "targetBlend1Changed",
        "targetBlend2Changed",
        "targetBlend3Changed",
        "targetBlend4Changed",
        "targetBlend5Changed",
        "targetBlend6Changed",
        "targetBlend7Changed",
        "depthTestEnabled",
        "depthWriteEnabled",
        "blendEnabled",
        "usesStencilReference",
        "usesScissor",
        "depthFunction",
        "CompareOperation",
        "cullMode",
        "CullMode",
        "polygonMode",
        "PolygonMode",
        "stencilWriteMask",
        "stencilReference",
        "viewport",
        "QRectF",
        "scissor",
        "QRect",
        "targetBlend0",
        "QQuick3DRenderPassTargetBlend",
        "targetBlend1",
        "targetBlend2",
        "targetBlend3",
        "targetBlend4",
        "targetBlend5",
        "targetBlend6",
        "targetBlend7",
        "Never",
        "Less",
        "Equal",
        "LessOrEqual",
        "Greater",
        "NotEqual",
        "GreaterOrEqual",
        "Always",
        "None",
        "Front",
        "Back",
        "Fill",
        "Line"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'depthTestEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthWriteEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blendEnabledChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usesStencilReferenceChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usesScissorChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthFunctionChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cullModeChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'polygonModeChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stencilWriteMaskChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stencilReferenceChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewportChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scissorChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend0Changed'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend1Changed'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend2Changed'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend3Changed'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend4Changed'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend5Changed'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend6Changed'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetBlend7Changed'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'depthTestEnabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 0),
        // property 'depthWriteEnabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 1),
        // property 'blendEnabled'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 2),
        // property 'usesStencilReference'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 3),
        // property 'usesScissor'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 4),
        // property 'depthFunction'
        QtMocHelpers::PropertyData<enum CompareOperation>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'cullMode'
        QtMocHelpers::PropertyData<enum CullMode>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'polygonMode'
        QtMocHelpers::PropertyData<enum PolygonMode>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'stencilWriteMask'
        QtMocHelpers::PropertyData<quint32>(37, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 8),
        // property 'stencilReference'
        QtMocHelpers::PropertyData<quint32>(38, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 9),
        // property 'viewport'
        QtMocHelpers::PropertyData<QRectF>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'scissor'
        QtMocHelpers::PropertyData<QRect>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'targetBlend0'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'targetBlend1'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(45, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'targetBlend2'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(46, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
        // property 'targetBlend3'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(47, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'targetBlend4'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(48, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'targetBlend5'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(49, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'targetBlend6'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(50, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'targetBlend7'
        QtMocHelpers::PropertyData<QQuick3DRenderPassTargetBlend>(51, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CompareOperation'
        QtMocHelpers::EnumData<enum CompareOperation>(32, 32, QMC::EnumIsScoped).add({
            {   52, CompareOperation::Never },
            {   53, CompareOperation::Less },
            {   54, CompareOperation::Equal },
            {   55, CompareOperation::LessOrEqual },
            {   56, CompareOperation::Greater },
            {   57, CompareOperation::NotEqual },
            {   58, CompareOperation::GreaterOrEqual },
            {   59, CompareOperation::Always },
        }),
        // enum 'CullMode'
        QtMocHelpers::EnumData<enum CullMode>(34, 34, QMC::EnumIsScoped).add({
            {   60, CullMode::None },
            {   61, CullMode::Front },
            {   62, CullMode::Back },
        }),
        // enum 'PolygonMode'
        QtMocHelpers::EnumData<enum PolygonMode>(36, 36, QMC::EnumIsScoped).add({
            {   63, PolygonMode::Fill },
            {   64, PolygonMode::Line },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsPipelineStateOverride, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsPipelineStateOverride::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QQuick3DShaderUtilsPipelineStateOverrideE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QQuick3DShaderUtilsPipelineStateOverrideE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN40QQuick3DShaderUtilsPipelineStateOverrideE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsPipelineStateOverride::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsPipelineStateOverride *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->depthTestEnabledChanged(); break;
        case 1: _t->depthWriteEnabledChanged(); break;
        case 2: _t->blendEnabledChanged(); break;
        case 3: _t->usesStencilReferenceChanged(); break;
        case 4: _t->usesScissorChanged(); break;
        case 5: _t->depthFunctionChanged(); break;
        case 6: _t->cullModeChanged(); break;
        case 7: _t->polygonModeChanged(); break;
        case 8: _t->stencilWriteMaskChanged(); break;
        case 9: _t->stencilReferenceChanged(); break;
        case 10: _t->viewportChanged(); break;
        case 11: _t->scissorChanged(); break;
        case 12: _t->targetBlend0Changed(); break;
        case 13: _t->targetBlend1Changed(); break;
        case 14: _t->targetBlend2Changed(); break;
        case 15: _t->targetBlend3Changed(); break;
        case 16: _t->targetBlend4Changed(); break;
        case 17: _t->targetBlend5Changed(); break;
        case 18: _t->targetBlend6Changed(); break;
        case 19: _t->targetBlend7Changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::depthTestEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::depthWriteEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::blendEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::usesStencilReferenceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::usesScissorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::depthFunctionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::cullModeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::polygonModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::stencilWriteMaskChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::stencilReferenceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::viewportChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::scissorChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend0Changed, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend1Changed, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend2Changed, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend3Changed, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend4Changed, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend5Changed, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend6Changed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsPipelineStateOverride::*)()>(_a, &QQuick3DShaderUtilsPipelineStateOverride::targetBlend7Changed, 19))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->depthTestEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->depthWriteEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->blendEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->usesStencilReference(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->usesScissor(); break;
        case 5: *reinterpret_cast<enum CompareOperation*>(_v) = _t->depthFunction(); break;
        case 6: *reinterpret_cast<enum CullMode*>(_v) = _t->cullMode(); break;
        case 7: *reinterpret_cast<enum PolygonMode*>(_v) = _t->polygonMode(); break;
        case 8: *reinterpret_cast<quint32*>(_v) = _t->stencilWriteMask(); break;
        case 9: *reinterpret_cast<quint32*>(_v) = _t->stencilReference(); break;
        case 10: *reinterpret_cast<QRectF*>(_v) = _t->viewport(); break;
        case 11: *reinterpret_cast<QRect*>(_v) = _t->scissor(); break;
        case 12: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend0(); break;
        case 13: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend1(); break;
        case 14: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend2(); break;
        case 15: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend3(); break;
        case 16: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend4(); break;
        case 17: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend5(); break;
        case 18: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend6(); break;
        case 19: *reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v) = _t->targetBlend7(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDepthTestEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setDepthWriteEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setBlendEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setUsesStencilReference(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setUsesScissor(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setDepthFunction(*reinterpret_cast<enum CompareOperation*>(_v)); break;
        case 6: _t->setCullMode(*reinterpret_cast<enum CullMode*>(_v)); break;
        case 7: _t->setPolygonMode(*reinterpret_cast<enum PolygonMode*>(_v)); break;
        case 8: _t->setStencilWriteMask(*reinterpret_cast<quint32*>(_v)); break;
        case 9: _t->setStencilReference(*reinterpret_cast<quint32*>(_v)); break;
        case 10: _t->setViewport(*reinterpret_cast<QRectF*>(_v)); break;
        case 11: _t->setScissor(*reinterpret_cast<QRect*>(_v)); break;
        case 12: _t->setTargetBlend0(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 13: _t->setTargetBlend1(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 14: _t->setTargetBlend2(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 15: _t->setTargetBlend3(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 16: _t->setTargetBlend4(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 17: _t->setTargetBlend5(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 18: _t->setTargetBlend6(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        case 19: _t->setTargetBlend7(*reinterpret_cast<QQuick3DRenderPassTargetBlend*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetDepthTestEnabled(); break;
        case 1: _t->resetDepthWriteEnabled(); break;
        case 2: _t->resetBlendEnabled(); break;
        case 3: _t->resetUsesStencilReference(); break;
        case 4: _t->resetUsesScissor(); break;
        case 5: _t->resetDepthFunction(); break;
        case 6: _t->resetCullMode(); break;
        case 7: _t->resetPolygonMode(); break;
        case 8: _t->resetStencilWriteMask(); break;
        case 9: _t->resetStencilReference(); break;
        case 10: _t->resetViewport(); break;
        case 11: _t->resetScissor(); break;
        case 12: _t->resetTargetBlend0(); break;
        case 13: _t->resetTargetBlend1(); break;
        case 14: _t->resetTargetBlend2(); break;
        case 15: _t->resetTargetBlend3(); break;
        case 16: _t->resetTargetBlend4(); break;
        case 17: _t->resetTargetBlend5(); break;
        case 18: _t->resetTargetBlend6(); break;
        case 19: _t->resetTargetBlend7(); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsPipelineStateOverride::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsPipelineStateOverride::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QQuick3DShaderUtilsPipelineStateOverrideE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsPipelineStateOverride::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsPipelineStateOverride::depthTestEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DShaderUtilsPipelineStateOverride::depthWriteEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DShaderUtilsPipelineStateOverride::blendEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DShaderUtilsPipelineStateOverride::usesStencilReferenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DShaderUtilsPipelineStateOverride::usesScissorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DShaderUtilsPipelineStateOverride::depthFunctionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DShaderUtilsPipelineStateOverride::cullModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DShaderUtilsPipelineStateOverride::polygonModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DShaderUtilsPipelineStateOverride::stencilWriteMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DShaderUtilsPipelineStateOverride::stencilReferenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DShaderUtilsPipelineStateOverride::viewportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DShaderUtilsPipelineStateOverride::scissorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend0Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend3Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend4Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend5Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend6Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void QQuick3DShaderUtilsPipelineStateOverride::targetBlend7Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}
namespace {
struct qt_meta_tag_ZN29QQuick3DShaderUtilsApplyValueE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsApplyValue::qt_create_metaobjectdata<qt_meta_tag_ZN29QQuick3DShaderUtilsApplyValueE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsApplyValue",
        "QML.Element",
        "SetUniformValue",
        "target",
        "value",
        "QVariant"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QByteArray>(3, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsApplyValue, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsApplyValue::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DShaderUtilsApplyValueE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DShaderUtilsApplyValueE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQuick3DShaderUtilsApplyValueE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsApplyValue::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsApplyValue *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->target; break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->value; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->target, *reinterpret_cast<QByteArray*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->value, *reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsApplyValue::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsApplyValue::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DShaderUtilsApplyValueE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsApplyValue::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN36QQuick3DShaderUtilsRenderablesFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderablesFilter::qt_create_metaobjectdata<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderablesFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderablesFilter",
        "QML.Element",
        "RenderablesFilter",
        "QML.AddedInVersion",
        "1547",
        "layerMask",
        "renderableTypes",
        "RenderableTypes",
        "RenderableType",
        "None",
        "Opaque",
        "Transparent"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'layerMask'
        QtMocHelpers::PropertyData<quint32>(5, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'renderableTypes'
        QtMocHelpers::PropertyData<RenderableTypes>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'RenderableTypes'
        QtMocHelpers::EnumData<RenderableTypes>(7, 8, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {    9, RenderableType::None },
            {   10, RenderableType::Opaque },
            {   11, RenderableType::Transparent },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderablesFilter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderablesFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderablesFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderablesFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderablesFilterE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderablesFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderablesFilter *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<quint32*>(_v) = _t->layerMask; break;
        case 1: QtMocHelpers::assignFlags<RenderableTypes>(_v, _t->renderableTypes()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->layerMask, *reinterpret_cast<quint32*>(_v)); break;
        case 1: _t->setRenderableTypes(*reinterpret_cast<RenderableTypes*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderablesFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderablesFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderablesFilterE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderablesFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN36QQuick3DShaderUtilsRenderPassTextureE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderPassTexture::qt_create_metaobjectdata<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderPassTextureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderPassTexture",
        "QML.Element",
        "RenderPassTexture",
        "QML.AddedInVersion",
        "1547",
        "format",
        "TextureFormat",
        "Unknown",
        "RGBA8",
        "RGBA16F",
        "RGBA32F",
        "R8",
        "R16",
        "R16F",
        "R32F",
        "Depth16",
        "Depth24",
        "Depth32",
        "Depth24Stencil8"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'format'
        QtMocHelpers::PropertyData<enum TextureFormat>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TextureFormat'
        QtMocHelpers::EnumData<enum TextureFormat>(6, 6, QMC::EnumIsScoped).add({
            {    7, TextureFormat::Unknown },
            {    8, TextureFormat::RGBA8 },
            {    9, TextureFormat::RGBA16F },
            {   10, TextureFormat::RGBA32F },
            {   11, TextureFormat::R8 },
            {   12, TextureFormat::R16 },
            {   13, TextureFormat::R16F },
            {   14, TextureFormat::R32F },
            {   15, TextureFormat::Depth16 },
            {   16, TextureFormat::Depth24 },
            {   17, TextureFormat::Depth32 },
            {   18, TextureFormat::Depth24Stencil8 },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderPassTexture, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderPassTexture::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderPassTextureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderPassTextureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderPassTextureE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderPassTexture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderPassTexture *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum TextureFormat*>(_v) = _t->format(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFormat(*reinterpret_cast<enum TextureFormat*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderPassTexture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderPassTexture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36QQuick3DShaderUtilsRenderPassTextureE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderPassTexture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN44QQuick3DShaderUtilsRenderPassColorAttachmentE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderPassColorAttachment::qt_create_metaobjectdata<qt_meta_tag_ZN44QQuick3DShaderUtilsRenderPassColorAttachmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderPassColorAttachment",
        "QML.Element",
        "ColorAttachment",
        "QML.AddedInVersion",
        "1547",
        "target",
        "QQuick3DShaderUtilsRenderPassTexture*",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QQuick3DShaderUtilsRenderPassTexture*>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'name'
        QtMocHelpers::PropertyData<QByteArray>(7, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderPassColorAttachment, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderPassColorAttachment::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44QQuick3DShaderUtilsRenderPassColorAttachmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44QQuick3DShaderUtilsRenderPassColorAttachmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN44QQuick3DShaderUtilsRenderPassColorAttachmentE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderPassColorAttachment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderPassColorAttachment *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DShaderUtilsRenderPassTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DShaderUtilsRenderPassTexture**>(_v) = _t->target; break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->name(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->target, *reinterpret_cast<QQuick3DShaderUtilsRenderPassTexture**>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QByteArray*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderPassColorAttachment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderPassColorAttachment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44QQuick3DShaderUtilsRenderPassColorAttachmentE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderPassColorAttachment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthTextureAttachmentE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderPassDepthTextureAttachment::qt_create_metaobjectdata<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthTextureAttachmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderPassDepthTextureAttachment",
        "QML.Element",
        "DepthTextureAttachment",
        "QML.AddedInVersion",
        "1547",
        "target",
        "QQuick3DShaderUtilsRenderPassTexture*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QQuick3DShaderUtilsRenderPassTexture*>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderPassDepthTextureAttachment, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderPassDepthTextureAttachment::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthTextureAttachmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthTextureAttachmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthTextureAttachmentE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderPassDepthTextureAttachment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderPassDepthTextureAttachment *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DShaderUtilsRenderPassTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DShaderUtilsRenderPassTexture**>(_v) = _t->target; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->target, *reinterpret_cast<QQuick3DShaderUtilsRenderPassTexture**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderPassDepthTextureAttachment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderPassDepthTextureAttachment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthTextureAttachmentE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderPassDepthTextureAttachment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthStencilAttachmentE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderPassDepthStencilAttachment::qt_create_metaobjectdata<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthStencilAttachmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderPassDepthStencilAttachment",
        "QML.Element",
        "DepthStencilAttachment",
        "QML.AddedInVersion",
        "1547"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderPassDepthStencilAttachment, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderPassDepthStencilAttachment::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthStencilAttachmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthStencilAttachmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthStencilAttachmentE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderPassDepthStencilAttachment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderPassDepthStencilAttachment *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QQuick3DShaderUtilsRenderPassDepthStencilAttachment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderPassDepthStencilAttachment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN51QQuick3DShaderUtilsRenderPassDepthStencilAttachmentE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderPassDepthStencilAttachment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN38QQuick3DShaderUtilsRenderPassAddDefineE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderPassAddDefine::qt_create_metaobjectdata<qt_meta_tag_ZN38QQuick3DShaderUtilsRenderPassAddDefineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderPassAddDefine",
        "QML.Element",
        "AddDefine",
        "QML.AddedInVersion",
        "1547",
        "nameChanged",
        "",
        "valueChanged",
        "name",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QByteArray>(8, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'value'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderPassAddDefine, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderPassAddDefine::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38QQuick3DShaderUtilsRenderPassAddDefineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38QQuick3DShaderUtilsRenderPassAddDefineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38QQuick3DShaderUtilsRenderPassAddDefineE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderPassAddDefine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderPassAddDefine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->valueChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsRenderPassAddDefine::*)()>(_a, &QQuick3DShaderUtilsRenderPassAddDefine::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsRenderPassAddDefine::*)()>(_a, &QQuick3DShaderUtilsRenderPassAddDefine::valueChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QByteArray*>(_v)); break;
        case 1: _t->setValue(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderPassAddDefine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderPassAddDefine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38QQuick3DShaderUtilsRenderPassAddDefineE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderPassAddDefine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsRenderPassAddDefine::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DShaderUtilsRenderPassAddDefine::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN32QQuick3DShaderUtilsSubRenderPassE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsSubRenderPass::qt_create_metaobjectdata<qt_meta_tag_ZN32QQuick3DShaderUtilsSubRenderPassE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsSubRenderPass",
        "QML.Element",
        "SubRenderPass",
        "QML.AddedInVersion",
        "1547",
        "renderPassChanged",
        "",
        "renderPass",
        "QQuick3DRenderPass*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'renderPassChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'renderPass'
        QtMocHelpers::PropertyData<QQuick3DRenderPass*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsSubRenderPass, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsSubRenderPass::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DShaderUtilsRenderCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DShaderUtilsSubRenderPassE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DShaderUtilsSubRenderPassE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32QQuick3DShaderUtilsSubRenderPassE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsSubRenderPass::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsSubRenderPass *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->renderPassChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsSubRenderPass::*)()>(_a, &QQuick3DShaderUtilsSubRenderPass::renderPassChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DRenderPass**>(_v) = _t->renderPass(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRenderPass(*reinterpret_cast<QQuick3DRenderPass**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsSubRenderPass::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsSubRenderPass::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DShaderUtilsSubRenderPassE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DShaderUtilsRenderCommand::qt_metacast(_clname);
}

int QQuick3DShaderUtilsSubRenderPass::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DShaderUtilsRenderCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsSubRenderPass::renderPassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN29QQuick3DShaderUtilsRenderPassE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsRenderPass::qt_create_metaobjectdata<qt_meta_tag_ZN29QQuick3DShaderUtilsRenderPassE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsRenderPass",
        "QML.Element",
        "Pass",
        "QML.AddedInVersion",
        "1547",
        "changed",
        "",
        "commands",
        "QQmlListProperty<QQuick3DShaderUtilsRenderCommand>",
        "output",
        "QQuick3DShaderUtilsBuffer*",
        "shaders",
        "QQmlListProperty<QQuick3DShaderUtilsShader>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'commands'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DShaderUtilsRenderCommand>>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'output'
        QtMocHelpers::PropertyData<QQuick3DShaderUtilsBuffer*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'shaders'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DShaderUtilsShader>>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsRenderPass, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsRenderPass::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DShaderUtilsRenderPassE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DShaderUtilsRenderPassE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQuick3DShaderUtilsRenderPassE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsRenderPass::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsRenderPass *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsRenderPass::*)()>(_a, &QQuick3DShaderUtilsRenderPass::changed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DShaderUtilsBuffer* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QQuick3DShaderUtilsRenderCommand>*>(_v) = _t->commands(); break;
        case 1: *reinterpret_cast<QQuick3DShaderUtilsBuffer**>(_v) = _t->outputBuffer; break;
        case 2: *reinterpret_cast<QQmlListProperty<QQuick3DShaderUtilsShader>*>(_v) = _t->shaders(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: QtMocHelpers::setProperty(_t->outputBuffer, *reinterpret_cast<QQuick3DShaderUtilsBuffer**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsRenderPass::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsRenderPass::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DShaderUtilsRenderPassE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DShaderUtilsRenderPass::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsRenderPass::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN25QQuick3DShaderUtilsShaderE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DShaderUtilsShader::qt_create_metaobjectdata<qt_meta_tag_ZN25QQuick3DShaderUtilsShaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DShaderUtilsShader",
        "QML.Element",
        "Shader",
        "shaderChanged",
        "",
        "stageChanged",
        "shader",
        "QUrl",
        "stage",
        "Stage",
        "Vertex",
        "Fragment"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shaderChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stageChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shader'
        QtMocHelpers::PropertyData<QUrl>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'stage'
        QtMocHelpers::PropertyData<enum Stage>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Stage'
        QtMocHelpers::EnumData<enum Stage>(9, 9, QMC::EnumIsScoped).add({
            {   10, Stage::Vertex },
            {   11, Stage::Fragment },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DShaderUtilsShader, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DShaderUtilsShader::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DShaderUtilsShaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DShaderUtilsShaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQuick3DShaderUtilsShaderE_t>.metaTypes,
    nullptr
} };

void QQuick3DShaderUtilsShader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DShaderUtilsShader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shaderChanged(); break;
        case 1: _t->stageChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsShader::*)()>(_a, &QQuick3DShaderUtilsShader::shaderChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DShaderUtilsShader::*)()>(_a, &QQuick3DShaderUtilsShader::stageChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->shader; break;
        case 1: *reinterpret_cast<enum Stage*>(_v) = _t->stage; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->shader, *reinterpret_cast<QUrl*>(_v)))
                Q_EMIT _t->shaderChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->stage, *reinterpret_cast<enum Stage*>(_v)))
                Q_EMIT _t->stageChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DShaderUtilsShader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DShaderUtilsShader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DShaderUtilsShaderE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DShaderUtilsShader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DShaderUtilsShader::shaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DShaderUtilsShader::stageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DPropertyWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DPropertyWatcher",
        "onValuePropertyChanged",
        "",
        "onPointerPropertyChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onValuePropertyChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPointerPropertyChanged'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DPropertyWatcher, qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DPropertyWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t>.metaTypes,
    nullptr
} };

void QQuick3DPropertyWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DPropertyWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onValuePropertyChanged(); break;
        case 1: _t->onPointerPropertyChanged(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *QQuick3DPropertyWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DPropertyWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DPropertyWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DPropertyWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN32QQuick3DRenderTargetBlendForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRenderTargetBlendForeign::qt_create_metaobjectdata<qt_meta_tag_ZN32QQuick3DRenderTargetBlendForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRenderTargetBlendForeign",
        "QML.Foreign",
        "QQuick3DRenderPassTargetBlend",
        "QML.ForeignIsNamespace",
        "true",
        "QML.Element",
        "RenderTargetBlend",
        "QML.AddedInVersion",
        "1547"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN32QQuick3DRenderTargetBlendForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN32QQuick3DRenderTargetBlendForeignE =
    QQuick3DRenderTargetBlendForeign::qt_create_metaobjectdata<qt_meta_tag_ZN32QQuick3DRenderTargetBlendForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN32QQuick3DRenderTargetBlendForeignE =
    qt_staticMetaObjectContent_ZN32QQuick3DRenderTargetBlendForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN32QQuick3DRenderTargetBlendForeignE =
    qt_staticMetaObjectContent_ZN32QQuick3DRenderTargetBlendForeignE.relocatingData;

Q_CONSTINIT const QMetaObject QQuick3DRenderTargetBlendForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN32QQuick3DRenderTargetBlendForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN32QQuick3DRenderTargetBlendForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN32QQuick3DRenderTargetBlendForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
